import { useAjax } from '@/Hook/useAjax';
import {
  apibookAuthorAdd,
  apibookAuthorDel,
  apibookAuthorEdit,
  apibookAuthorList,
} from '@/services/book/author';
import { PlusCircleOutlined } from '@ant-design/icons';
import {
  ActionType,
  BetaSchemaForm,
  PageContainer,
  ProFormInstance,
  ProTable,
} from '@ant-design/pro-components';
import { Button, message } from 'antd';
import { useRef, useState } from 'react';
import formConfig from './formConfig';
import { columns } from './tableConfig';

type DataItem = {
  name: string;
  state: string;
};
const Page: React.FC = () => {
  const formRef = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();
  let [open, setOpen] = useState<any>(null); //新增作者
  let [editValues, setEditValues] = useState<any>({});
  let bookAuthorList = useAjax((params) => apibookAuthorList(params), { type: 'table' });
  let bookAuthorEdit = useAjax((params) => apibookAuthorEdit(params));
  let bookAuthorAdd = useAjax((params) => apibookAuthorAdd(params));
  let bookAuthorDel = useAjax((params) => apibookAuthorDel(params));

  // 编辑
  const edit = (item: any) => {
    setEditValues(item);
    setTimeout(() => {
      formRef?.current?.setFieldsValue({ ...item });
    }, 100);
    setOpen(true);
  };
  // 删除
  const del = (id: any) => {
    bookAuthorDel.run(id).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('删除成功');
      }
    });
  };
  // 新增 or 编辑
  const submit = async (values: any) => {
    let api = editValues?.id ? bookAuthorEdit : bookAuthorAdd;
    if (editValues?.id) {
      values.id = editValues?.id;
    }
    api.run(values).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('操作成功!');
        closeForm(false);
      }
    });
    console.log(values);
  };
  // 关闭表单弹窗和重置表单内容
  const closeForm = (b: boolean, values?: any) => {
    if (!b) {
      setEditValues({});
      formRef?.current?.resetFields?.();
      setOpen(b);
    } else {
    }
  };
  return (
    <PageContainer>
      <ProTable<any, any>
        headerTitle={'作者列表'}
        actionRef={actionRef}
        rowKey={(r) => r.id}
        search={{
          labelWidth: 120,
        }}
        request={async (params) => {
          return await bookAuthorList.run(params);
        }}
        scroll={{ x: 'auto' }}
        toolBarRender={() => {
          return [
            <Button
              type="primary"
              onClick={() => {
                setOpen(true);
              }}
            >
              <PlusCircleOutlined />
              新增作者
            </Button>,
          ];
        }}
        columns={columns(edit, del)}
        // bordered
      />
      <BetaSchemaForm<DataItem>
        title={!editValues?.id ? '新增作者' : '编辑作者'}
        formRef={formRef}
        width={600}
        open={open}
        onOpenChange={(b) => {
          !b && closeForm(b);
        }}
        layoutType={'ModalForm'}
        labelCol={{ span: 6 }}
        wrapperCol={{ span: 14 }}
        // grid={true}
        layout="horizontal"
        onFinish={submit}
        columns={formConfig()}
        loading={bookAuthorEdit?.loading || bookAuthorAdd?.loading}
      />
    </PageContainer>
  );
};
export default Page;
