import UploadImg from '@/components/uploadImg';
import { ProFormColumnsType } from '@ant-design/pro-components';

function formConfig(props: {
  authList?: any[];
  enumList?: { [key: string]: any };
  labelList?: any[];
  categoryList?: any[];
}): ProFormColumnsType<{
  name: string;
  state: string;
}>[] {
  let { enumList, labelList, categoryList, authList } = props;
  return [
    {
      valueType: 'group',
      colProps: {
        span: 12,
      },
      rowProps: { gutter: [14, 14] },
      columns: [
        {
          title: '频道',
          dataIndex: 'workDirection',
          valueType: 'select',
          fieldProps: { showSearch: true, placeholder: '请选择频道' },
          colProps: {
            span: 24,
          },
          formItemProps: {
            style: { marginBottom: 10 },
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
          valueEnum: () => {
            let arr = enumList?.WORK_DIRECTION?.values;
            return new Map(arr?.map(({ value, description }: any) => [value, description]));
          },
        },
        {
          valueType: 'dependency',
          name: ['workDirection'],
          columns: ({ workDirection }) => {
            console.log('workDirection', workDirection);
            return [
              {
                title: '分类',
                dataIndex: 'categoryId',
                valueType: 'select',
                fieldProps: {
                  showSearch: true,
                  placeholder: '请选择分类',
                  disabled: workDirection != 0 && workDirection != 1,
                },
                colProps: {
                  span: 24,
                },
                formItemProps: {
                  style: { marginBottom: 10 },
                  rules: [
                    {
                      required: true,
                      message: '此项为必填项',
                    },
                  ],
                },
                valueEnum: () => {
                  let arr = categoryList || [];
                  return new Map([...arr]?.map((item) => [item.id, item.name]));
                },
              },
              {
                title: '标签',
                dataIndex: 'labelIds',
                valueType: 'select',
                colProps: {
                  span: 24,
                },
                formItemProps: {
                  style: { marginBottom: 10 },
                  rules: [
                    {
                      required: true,
                      message: '此项为必填项',
                    },
                  ],
                },
                convertValue: (value) => {
                  let arr =
                    typeof value === 'string' ? value?.split(',')?.map((s) => Number(s)) : value;
                  return arr;
                },
                transform: (value) => {
                  return typeof value != 'string' ? value.join() : value;
                },
                fieldProps: {
                  mode: 'multiple',
                  showSearch: true,
                  placeholder: '请选择标签',
                  disabled: workDirection != 0 && workDirection != 1,
                },
                valueEnum: () => {
                  let arr = labelList || [];
                  return new Map([...arr]?.map((item) => [item.id, item.name]));
                },
              },
            ];
          },
        },
        {
          title: '书名',
          dataIndex: 'bookName',
          colProps: {
            span: 24,
          },
          fieldProps: { placeholder: '请输入小说名称' },
          formItemProps: {
            style: { marginBottom: 10 },
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
        },
        {
          title: '作者',
          dataIndex: 'authorId',
          valueType: 'select',
          fieldProps: { showSearch: true, placeholder: '请选择作者' },
          colProps: {
            span: 24,
          },
          formItemProps: {
            style: { marginBottom: 10 },
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
          valueEnum: new Map(authList?.map(({ id, authorName }) => [id, authorName])),
        },
        {
          title: '来源',
          dataIndex: 'source',
          valueType: 'select',
          fieldProps: { showSearch: true, placeholder: '请选择来源' },
          colProps: {
            span: 24,
          },
          formItemProps: {
            style: { marginBottom: 10 },
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
          valueEnum: () => {
            let arr = enumList?.SOURCE?.values;
            return arr
              ? new Map([...arr]?.map(({ value, description }: any) => [value, description]))
              : {};
          },
        },
        {
          title: '描述',
          dataIndex: 'bookDesc',
          valueType: 'textarea',
          colProps: {
            span: 24,
          },
          fieldProps: { placeholder: '请输入小说描述' },
          formItemProps: {
            style: { marginBottom: 10 },
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
        },
      ],
    },
    {
      valueType: 'group',
      colProps: {
        span: 12,
      },
      rowProps: { gutter: [14, 14] },
      columns: [
        {
          title: '书籍状态',
          dataIndex: 'bookStatus',
          valueType: 'select',
          colProps: {
            span: 24,
          },
          formItemProps: {
            style: { marginBottom: 10 },
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
          valueEnum: () => {
            let arr = enumList?.BOOK_STATUS?.values;
            return new Map(arr?.map(({ value, description }: any) => [value, description]));
          },
        },
        {
          title: '上架状态',
          dataIndex: 'shelveStatus',
          valueType: 'select',
          colProps: {
            span: 24,
          },
          formItemProps: {
            style: { marginBottom: 10 },
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
          valueEnum: () => {
            let arr = enumList?.SHELVE_STATUS?.values;
            return new Map(arr?.map(({ value, description }: any) => [value, description]));
          },
        },
        {
          title: '封面',
          dataIndex: 'picUrl',
          colProps: {
            span: 24,
          },
          formItemProps: {
            style: { marginBottom: 10 },
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
          renderFormItem: () => {
            return (
              <UploadImg
                size={{
                  width: 300,
                  height: 400,
                  evalW: '!=',
                  evalH: '!=',
                  msg: '需要图片大小300*400',
                }}
                isEdit={true}
                type="image"
                isCropper
              />
            );
          },
        },
      ],
    },
  ];
}

export default formConfig;
