import { ProFormColumnsType } from '@ant-design/pro-components';

function formConfig(props: {
  enumList?: { [key: string]: any };
  bookList?: any[];
  distributorInfoList?: any[];
}): ProFormColumnsType<{
  name: string;
  state: string;
}>[] {
  let { enumList, bookList, distributorInfoList } = props;
  return [
    {
      title: 'VIP免费',
      dataIndex: 'vipFree',
      valueType: 'radio',
      valueEnum: () => {
        let arr = enumList?.VIP_FREE?.values;
        return arr
          ? new Map([...arr]?.map(({ value, description }: any) => [value, description]))
          : {};
      },
      formItemProps: {
        style: { marginBottom: 10 },
        rules: [
          {
            required: true,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      title: '付费类型',
      dataIndex: 'paymentType',
      valueType: 'radio',
      valueEnum: () => {
        let arr = enumList?.PAYMENT_TYPE?.values;
        return arr
          ? new Map([...arr]?.map(({ value, description }: any) => [value, description]))
          : {};
      },
      formItemProps: {
        style: { marginBottom: 10 },
        rules: [
          {
            required: true,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      valueType: 'dependency',
      name: ['paymentType'],
      columns: ({ paymentType }) => {
        return [
          {
            title: '收费类型',
            dataIndex: 'paymentOption',
            valueType: 'radio',
            hideInForm: paymentType != 2,
            valueEnum: () => {
              let arr = enumList?.PAYMENT_OPTION?.values;
              return arr
                ? new Map([...arr]?.map(({ value, description }: any) => [value, description]))
                : {};
            },
            formItemProps: {
              style: { marginBottom: 10 },
              rules: [
                {
                  required: true,
                  message: '此项为必填项',
                },
              ],
            },
          },
          {
            title: '收费货币',
            dataIndex: 'paymentCategory',
            valueType: 'radio',
            hideInForm: paymentType == 0,
            valueEnum: () => {
              let arr = enumList?.PAYMENT_CATEGORY?.values;
              return arr
                ? new Map([...arr]?.map(({ value, description }: any) => [value, description]))
                : {};
            },
            formItemProps: {
              style: { marginBottom: 10 },
              rules: [
                {
                  required: true,
                  message: '此项为必填项',
                },
              ],
            },
          },
          {
            title: '开始付费章节/段落',
            dataIndex: 'beginPayParagraphNo',
            valueType: 'select',
            fieldProps: { showSearch: true, placeholder: '开始付费章节/段落' },
            hideInForm: paymentType != 2,
            valueEnum: () => {
              let arr = bookList;
              return arr
                ? new Map(
                    [...arr]?.map(({ paragraphInfo: { paragraphNo, content } }: any) => [
                      paragraphNo,
                      content,
                    ]),
                  )
                : {};
            },
            formItemProps: {
              style: { marginBottom: 10 },
              rules: [
                {
                  required: true,
                  message: '此项为必填项',
                },
              ],
            },
          },
          {
            valueType: 'dependency',
            name: ['paymentCategory', 'paymentType'],
            columns: ({ paymentCategory, paymentType }) => {
              return [
                {
                  title: '收费书币',
                  dataIndex: 'paymentCoin',
                  valueType: 'digit',
                  hideInForm: paymentType === 0 || paymentCategory == 0,
                  formItemProps: {
                    style: { marginBottom: 10 },
                    min: 0,
                    rules: [
                      {
                        required: true,
                        message: '此项为必填项',
                      },
                    ],
                  },
                  fieldProps: {
                    min: 0,
                    addonAfter: '书币',
                    precision: 0,
                  },
                },
                {
                  title: '收费金额',
                  dataIndex: 'paymentAmount',
                  valueType: 'money',
                  hideInForm: paymentType === 0 || paymentCategory == 1,
                  formItemProps: {
                    style: { marginBottom: 10 },
                    rules: [
                      {
                        required: true,
                        message: '此项为必填项',
                      },
                    ],
                  },
                  fieldProps: {
                    min: 0,
                    addonAfter: '元',
                  },
                },
              ];
            },
          },
        ];
      },
    },
    {
      title: '是否开放给所有分销商',
      dataIndex: 'publicDistributor',
      valueType: 'radio',
      valueEnum: () => {
        let arr = enumList?.PUBLIC_DISTRIBUTOR?.values;
        return arr
          ? new Map([...arr]?.map(({ value, description }: any) => [value, description]))
          : {};
      },
      formItemProps: {
        style: { marginBottom: 10 },
        rules: [
          {
            required: true,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      title: '是否允许分销商配置价格',
      dataIndex: 'allowDistributorConfig',
      valueType: 'radio',
      valueEnum: () => {
        let arr = enumList?.ALLOW_DISTRIBUTOR_CONFIG?.values;
        return arr
          ? new Map([...arr]?.map(({ value, description }: any) => [value, description]))
          : {};
      },
      formItemProps: {
        style: { marginBottom: 10 },
        rules: [
          {
            required: true,
            message: '此项为必填项',
          },
        ],
      },
    },
    {
      dataIndex: 'bookDistributorConfig',
      valueType: 'formList',
      title: '小说分销商配置',
      fieldProps: {
        creatorButtonProps: {
          creatorButtonText: '新增小说分销商配置',
        },
      },
      formItemProps: {
        style: { marginBottom: 10 },
      },
      columns: [
        {
          valueType: 'group',
          fieldProps: {
            style: {
              display: 'flex',
              alignItems: 'center',
              flexFlow: 'row',
            },
          },
          columns: [
            {
              dataIndex: 'distributorId',
              fieldProps: { showSearch: true, placeholder: '请选择分销商' },
              colProps: { span: 10 },
              formItemProps: {
                style: { marginBottom: 10, minWidth: 150 },
                rules: [
                  {
                    required: true,
                    message: '此项为必填项',
                  },
                ],
              },
              valueEnum: () => {
                let arr = distributorInfoList;
                return arr
                  ? new Map([...arr]?.map(({ id, companyName }: any) => [id, companyName]))
                  : {};
              },
            },
            {
              valueType: 'dependency',
              name: ['configRelations'],
              columns({ configRelations }) {
                console.log('configRelations', configRelations);
                return [
                  {
                    valueType: 'checkbox',
                    dataIndex: 'configRelations',
                    colProps: { span: 14 },
                    formItemProps: {
                      style: { width: 300 },
                      rules: [
                        {
                          required: true,
                          message: '此项为必填项',
                        },
                      ],
                    },
                    valueEnum: (a) => {
                      let arr = enumList?.CONFIG_RELATIONS?.values;
                      let obj: any = {};
                      for (let item of arr) {
                        obj[item.value] = {
                          text: item.description,
                          disabled:
                            configRelations?.length > 0 && !configRelations.includes(item.value),
                        };
                      }
                      return obj;
                    },
                  },
                ];
              },
            },
          ],
        },
      ],
    },
  ];
}

export default formConfig;
