import UploadImg from '@/components/uploadImg';
import {
    ProCard,
    ProForm,
    ProFormGroup,
    ProFormInstance,
    ProFormItem,
    ProFormList,
    ProFormRadio,
    ProFormText,
    ProFormTextArea,
} from '@ant-design/pro-components';
import { forwardRef, useImperativeHandle, useRef } from 'react';
let rules = [{
    required: true,
    message: '此项为必填项',
}]
let options = [
    {
        value: true,
        label: "是"
    },
    {
        value: false,
        label: "否"
    },
]
const FormComp = forwardRef((props: any, ref?: any) => {
    const formRef = useRef<ProFormInstance>(); // 内部 formRef 供 ProForm 使用
    // 使用 useImperativeHandle 暴露方法给父组件
    useImperativeHandle(ref, () => ({
        ...formRef.current
    }));
    return (
        <ProForm onFinish={async (e) => console.log(e)} formRef={formRef} submitter={false}>
            <ProFormText name="templateName" label="模板名称" rules={rules} />
            <ProFormList
                name="appPageConfigDTOList"
                creatorButtonProps={
                    {creatorButtonText:"新增页面"}
                }
                // label="页面配置"
                itemRender={({ listDom, action }, { record }) => {
                    return (
                        <ProCard
                            bordered
                            extra={action}
                            title={record?.name}
                            style={{
                                marginBlockEnd: 8,
                            }}
                        >
                            {listDom}
                        </ProCard>
                    );
                }}
            >
                <ProForm.Group>
                    <ProFormGroup direction='vertical'>
                        <ProFormText name="pageName" label="页面名称" rules={rules} />
                        <ProFormText name="pagePath" label="页面路径" rules={rules} />
                    </ProFormGroup>
                    <ProFormGroup direction='vertical' >
                        <ProFormRadio.Group name="readingContent" label="是否阅读内容" options={options} initialValue={false} />
                        <ProFormRadio.Group name="enabledComponent" label="是否支持组件配置" options={options} initialValue={false} />
                    </ProFormGroup>
                    <ProFormGroup direction='vertical'>
                        <ProFormText name="shareTitles" label="分享标题" />
                        <ProFormTextArea name="pageDesc" label="页面描述" />
                    </ProFormGroup>
                    <ProForm.Item name="sharePicUrl" label="分享图片" >
                        <UploadImg
                            size={{
                                width: 300,
                                height: 400,
                                evalW: '!=',
                                evalH: '!=',
                                msg: '需要图片大小300*400',
                            }}
                            isEdit={true}
                            type="image"
                            isCropper
                        />
                    </ProForm.Item>
                </ProForm.Group>
            </ProFormList>
        </ProForm>
    );
});

export default FormComp;