/**
 * 生成新的本地路由菜单配置
 * @param {Array} localMenu - 本地菜单配置
 * @param {Array} onlineMenu - 线上菜单配置
 * @returns {Array} - 新的本地菜单配置
 */
// 用于将线上路由扁平化以便于查找
export function flattenRoutes(routes: any) {
  let result: any = {};
  for (const route of routes) {
    // console.log("route",route)
    result[route.path] = route;
    if (route.routes) {
      Object.assign(result, flattenRoutes(route.routes));
    }
  }
  return result;
}
export function generateNewLocalMenu(localMenu: any, onlineMenu: any) {
  // 递归重构线上菜单为本地菜单格式
  function transformOnlineMenu(menu: any) {
    return menu.map((item: any) => {
      let transformedItem = {
        path: item.path,
        name: item.title,
        component: item.component,
        routes: item.children ? transformOnlineMenu(item.children) : [],
      };
      return transformedItem;
    });
  }

  const transformedOnlineMenu = transformOnlineMenu(onlineMenu);

  //线上路由扁平
  const flatOnlineRoutes = flattenRoutes(transformedOnlineMenu);
  // 递归处理本地菜单，添加 access: "isHide"
  function processLocalRoutes(routes: any) {
    return routes.map((route: any) => {
      if (route.path === '/user' || route.path === '/' || route.path === '*') {
        return route;
      }
      if (!flatOnlineRoutes[route.path]) {
        return { ...route, access: 'isHide' };
      }
      if (route.routes) {
        return { ...route, routes: processLocalRoutes(route.routes) };
      }
      return route;
    });
  }

  const newLocalMenu = processLocalRoutes(localMenu);
  // console.log("newLocalMenu", newLocalMenu)
  // 本地新路由扁平
  const flatLocalRoutes = flattenRoutes(newLocalMenu);
  // 处理带有 redirect 的路由
  function adjustRedirects(routes: any, parentRoutes = []) {
    // console.log("routes",routes)
    return routes.reduce((result: any, route: any) => {
      if (route.redirect) {
        const targetRoute = flatLocalRoutes[route.redirect];
        if (targetRoute && targetRoute.access === 'isHide') {
          if (route.routes) {
            parentRoutes = route.routes;
          }
          const siblingRoutes: any = parentRoutes.filter(
            (r: any) =>
              r !== route &&
              (!r.access || r.access !== 'isHide') &&
              !r.path.match(/(^\/user$)|(^\*$)/g),
          );
          if (siblingRoutes.length > 0) {
            // console.log("route", route)
            // console.log("siblingRoutes[0]", siblingRoutes[0])
            // console.log("targetRoute", targetRoute)
            // console.log("parentRoutes", parentRoutes)
            route.redirect = siblingRoutes[0].path;
          } else {
            return result; // 删除当前路由
          }
        }
      }
      if (route.routes) {
        route.routes = adjustRedirects(route.routes, route.routes);
      }
      result.push(route);
      return result;
    }, []);
  }
  let finalLocalMenu = adjustRedirects(newLocalMenu, newLocalMenu);
  // 过滤掉带有 access: 'isHide' 的对象
  function filterRoutes(routes: any) {
    return routes
      .filter((route: { access: string }) => route.access !== 'isHide')
      .map((route: { routes: any }) =>
        route.routes
          ? {
              ...route,
              routes: filterRoutes(route.routes),
            }
          : route,
      );
  }
  finalLocalMenu = filterRoutes(finalLocalMenu);
  return finalLocalMenu;
}
